.. biosiglive documentation master file, created by
   sphinx-quickstart on Fri Jan 27 22:35:01 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Biosiglive: an Open Sources python package for real-time biosignals processing.
===============================================================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:
   
   about
   install
   APIDocumentation
   examples
   contributing
   cite


Content
==================

* :ref:`modindex`
* :ref:`search`

